# Example Package

This is a simple example package by Lomo.

# Content

```shell
/Users/lomo/Documents/codes/py_package/pkg_lomo
├── LICENSE
├── README.rst
├── pkg
└── setup.py
```

# Change Log

1、First submit, at 2021.11.20

2、add more func lib
